#pragma option -l; // Disable header inclusion in listing
/*
        MPC Code Development System
        Header file for PIC17C42         V1.10

                        17C42.H

        (c) Copyright 1994   Byte Craft Limited
        421 King St.N., Waterloo, ON, Canada, N2J 4E4

        Sherif Abdel-Kader
*/

// 16-bit core
#pragma has PIC16;

// Interrupt vectors
#pragma vector __RESET @ 0x0000;
#pragma vector __INT   @ 0x0008;
#pragma vector __RTCC  @ 0x0010;
#pragma vector __RTpin @ 0x0018;
#pragma vector __PIV   @ 0x0020;

// ROM and RAM size/starting address
#pragma option +l;
#define MAXROM 2009
#pragma memory ROM [MAXROM] @ 0x28;
#pragma memory RAM [232]    @ 0x18;
#pragma option -l; // Disable header inclusion in listing

// Special-purpose registers, Bank 0
#pragma portrw INDF0   @ 0x00;
#pragma portrw FSR0    @ 0x01;
#pragma portrw PCL     @ 0x02;
#pragma portrw PCLATH  @ 0x03;
#pragma portrw ALUSTA  @ 0x04;
#pragma portrw RTCSTA  @ 0x05;
#pragma portrw CPUSTA  @ 0x06;
#pragma portrw INTSTA  @ 0x07;
#pragma portrw FSR1    @ 0x09;
#pragma portrw WREG    @ 0x0A;
#pragma portrw RTCCL   @ 0x0B;
#pragma portrw RTCCH   @ 0x0C;
#pragma portrw TBLPTRL @ 0x0D;
#pragma portrw TBLPTRH @ 0x0E;
#pragma portrw BSR     @ 0x0F;
#pragma portrw PORTA   @ 0x10;
#pragma portrw DDRB    @ 0x11;
#pragma portrw PORTB   @ 0x12;
#pragma portrw RCSTA   @ 0x13;
#pragma portrw RCREG   @ 0x14;
#pragma portrw TXSTA   @ 0x15;
#pragma portrw TXREG   @ 0x16;
#pragma portrw SPBRG   @ 0x17;

// Special-purose registers, Bank 1
#pragma portrw DDRC    @ 0x110;
#pragma portrw PORTC   @ 0x111;
#pragma portrw DDRD    @ 0x112;
#pragma portrw PORTD   @ 0x113;
#pragma portrw DDRE    @ 0x114;
#pragma portrw PORTE   @ 0x115;
#pragma portrw PIR     @ 0x116;
#pragma portrw PIE     @ 0x117;

// Special-purpose registers, Bank 2
#pragma portrw TMR1    @ 0x210;
#pragma portrw TMR2    @ 0x211;
#pragma portrw TMR3L   @ 0x212;
#pragma portrw TMR3H   @ 0x213;
#pragma portrw PR1     @ 0x214;
#pragma portrw PR2     @ 0x215;
#pragma portrw PR3L    @ 0x216;
#pragma portrw PR3H    @ 0x217;
#pragma portrw CA1L    @ 0x216;
#pragma portrw CA1H    @ 0x217;

// Special-purpose registers, Bank 3
#pragma portrw PW1DCL  @ 0x310;
#pragma portrw PW2DCL  @ 0x311;
#pragma portrw PW1DCH  @ 0x312;
#pragma portrw PW2DCH  @ 0x313;
#pragma portrw CA2L    @ 0x314;
#pragma portrw CA2H    @ 0x315;
#pragma portrw TCON1   @ 0x316;
#pragma portrw TCON2   @ 0x317;

// INTSTA register bits
#define INTI1   0
#define T0IE    1
#define RTXIE   2
#define PEIE    3
#define INTIR   4
#define T0IR    5
#define RTXIR   6
#define PEIR    7

// PIR register bits
#define RBFL    0
#define TBMT    1
#define CA1IR   2
#define CA2IR   3
#define TM1IR   4
#define TM2IR   5
#define TM3IR   6
#define IRB     7

// PIE register bits
#define RCIE    0
#define TXIE    1
#define CA1IE   2
#define CA2IE   3
#define TM1IE   4
#define TM2IE   5
#define TM3IE   6
#define IEB     7

// RTCSTA register bits
#define RTPS0   1
#define RTPS1   2
#define RTPS2   3
#define RTPS3   4
#define T       5
#define T0EDG   6
#define INTEDG  7

// ALUSTA register bits
#define C       0
#define DC      1
#define Z       2
#define OV      3
#define FS0     4
#define FS1     5
#define FS2     6
#define FS3     7

// CPUSTA register bits
#define PD      2
#define TO      3
#define GLINTD  4
#define STKAV   5

// PORTA register bits (special pins only)
#define INT     0
#define T0CKI   1
#define RX      4  // Async. mode
#define DT      4  // Sync. mode
#define TX      5  // Async. mode
#define CK      5  // Sync. mode

// PORTB register bits (special pins only)
#define CAP1    0
#define CAP2    1
#define PWM1    2
#define PWM2    3
#define TCLK12  4
#define TCLK3   5

// PORTE register bits (special pins only)
#define ALE     0
#define OE      1
#define WR      2

// RCSTA register bits
#define RCD8    0
#define OERR    1
#define FERR    2
#define CREN    4
#define SREN    5
#define RC89    6
#define SPEN    7

//TXSTA register bits
#define TXD8    0
#define TRMT    1
#define SYNC    4
#define TXEN    5
#define TX89    6
#define CSRC    7

// RTCSTA register bits
#define RTPS0   1
#define RTPS1   2
#define RTPS2   3
#define RTPS3   4
#define T       5
#define RTEDG   6
#define INTEDG  7

// TCON1 register bits
#define TMR1C   0
#define TMR2C   1
#define TMR3C   2
#define T168    3
#define CA1ED0  4
#define CA1ED1  5
#define CA2ED0  6
#define CA2ED1  7

// TCON2 register bits
#define TMR1ON  0
#define TMR2ON  1
#define TMR3ON  2
#define CA1     3   // Same pin,
#define PR3     3   // different mode.
#define PWM1ON  4
#define PWM2ON  5
#define CA1OVF  6
#define CA2OVF  7

// Enable listing for user program
#pragma option +l;

