#pragma option v;

/*
   These routines may be adapted for any purpose when
   used with the MPC Code Development system.  No
   warranty is implied or given as to their usability
   for any purpose.

        (c) Copyright 1995

        Byte Craft Limited
        Waterloo, Ontario
        Canada N2J 4E4
        (519) 888-6911

        Sherif Abdel-Kader
*/

// Reading from & Writing to EEPROM memory
// on the PIC16C84 which has address range
// from 0x00 to 0x3F
// This simple program reads the value at
// memory location 0x26 in the EEPROM and
// writes it to location 0x27 in the EEPROM.

#include <16C84.h>

int addr, data;   // Used by eeprom functions

///////////////////////////////////////////////////
int eeprom_read(addr)
{
  EEADR = addr;   // Read from address
  EECON1.RD = 1;  // Set EECON1<0> to enable Read
  return(EEDATA); // Return value in data register
}
///////////////////////////////////////////////////
void eeprom_write(addr,data)
{
  INTCON.EEIE = 1;  // Enable EEPROM write interrupt
  EEADR = addr;     // Write to addres
  EEDATA = data;    // Data in data register
  EECON1.WREN = 1;  // Enable write to EEPROM
  STATUS.RP0 = 1;   // Set page 1 to access EECON1, EECON2
#asm
  MOVLW  55H        // Writing 0x55 must be followed
  MOVWF  09         // immediately by writing 0xAA
  MOVLW  0AAh       // to EECON2
  MOVWF  09
  BSF    08, WR
#endasm
}
///////////////////////////////////////////////////

void main()
{
//--------------- EEPROM READ ----------------
  addr = 0x26;   // Address to read from
  data = eeprom_read(addr);

//-------------- EEPROM  WRITE ----------------
  addr = 0x27;   // Address to write to
  do
    {
     eeprom_write(addr,data);
     while(!EECON1.EEIF);  // Loop till written
    }
  while (!EECON1.WRERR); // If erorr, retry
} // main()

