/*
   These routines may be adapted for any purpose when
   used with the MPC Code Development system.  No
   warranty is implied or given as to their usability
   for any purpose.

        (c) Copyright 1995

        Byte Craft Limited
        Waterloo, Ontario
        Canada N2J 4E4
        (519) 888-6911

        Sherif Abdel-Kader
*/

// Switching prescaler assignment from RTCC to WDT
// and vice versa on the PIC16C5X.
// This procedure must be followed
// in order to avoid an unintended RESET
//
// Note: This code was written with the emphasis
//       being on clarity rather than efficiency.
//

#include <16c54.h>

bits option;


void main() {


// ***** To switch prescaler assignment *****
// ***** from RTCC to WDT               *****

// The following statements are only
// needed if an external RTCC source is used
  option.PSA = 0;  // PSA = RTCC
  option.RTS = 0;  // RTCC source = internal clock
// For rate = 1:64 (for example),
// PS0=1, PS1=0, PS2=1
  option &= 0b11111000; // Mask off prescaler bits
  option |= 0b00000101; // Set prescale value
  __OPTION(option);    // Assign to OPTION

  RTCC = 0;        // Clear RTCC and prescaler
  option.PSA = 1;  // Select WDT, don't change
                   // prescaler value
  __OPTION(option);
  CLRWDT();        // Clear WDT and prescaler

// The following statements are needed only
// if the desired prescale value is '000' or '001'
// If rate of 1:2 for WDT is desired:
// PS0 = 1, PS1 = 0, PS2 =0
  option.PSA = 1;  // PSA = WDT
  option &= 0b11111000; // Mask off prescaler bits
  option |= 0b00000001; // Set prescale value
  __OPTION(option);


// ***** To switch prescaler assignment *****
// ***** from  WDT to RTCC              *****

  CLRWDT();     // Clear WDT and prescaler
  option.PSA = 0;      // PSA = RTCC
// If desired RTCC rate = 1:128 (for example)
// PS0 = 0, PS1 = 1, PS2 = 1
  option &= 0b11111000; // Mask off prescaler bits
  option |= 0b00000110; // Set prescale value
  __OPTION(option);    // Assign to OPTION
}  //main()
