/*
   These routines may be adapted for any purpose when
   used with the MPC Code Development system.  No
   warranty is implied or given as to their usability
   for any purpose.

        (c) Copyright 1988,1991,1994

        Byte Craft Limited
        Waterloo, Ontario
        Canada N2J 4E4
        (519) 888-6911

        Sherif Abdel-Kader
*/
// This example demonstrates the operation of
// the parallel slave port on the PIC16C64
//
// When an external RD or WR operation takes
// place, an interrupt occurs. The PC jumps
// to the __INT function where the PSPIF flag
// is checked to see if the slave port is the
// source of the interrupt. If so, program
// branches to handle_SLAVE(). If IBF is set,
// data is read from input buffer. If OBF is
// set, the PIC16C64 waits till the microprocessor
// reads the data. When OBF is cleared, the
// PIC16C64 writes the data to the output buffer.
//
// This program uses the PIC16C64 to obtain the
// 2's complement of the value passed to it
// by the microprocessor in the slave port.
// The then PIC16C64 reads the value, complements it
// then writes it to the output port. The
// microprocessor reads the complemented value
// from the output port.
//
// In general the microprocessor reads and writes
// to the slave port at a slower rate than the
// PIC16C64. This is because the PIC16C64 has means
// for checking the input and output slave port
// buffers whereas the microprocessor cannot.
//
// For simplicity, this program does not save W,
// RP0, or the Z flag during an interrupt. Please
// refer to ISR64.C which explains that.
//

#include <16C64.h>

void handle_TMR1();
void handle_SLAVE();

int data;

///////////////////////////////////////
//
void main() {
  // Disable all interrupts
     INTCON.GIE = 0;
  // Clear all 8 interrupt flag bits
     INTCON &= 0xF8; // Clear RB, INTF, T0
     PIR1 = 0;       // Clear TMR1,TMR2,CCP1,SSP,PSP
  // Enable TIMER1 and Slave port interrupts only
  // and mask off all the rest
     PIE1 = 0B10000001;
     INTCON = 0;
  // Enable unmasked interrupts
     INTCON.GIE = 1;
  // Loop until an interrupt occurs
     while(1) {
     }
}

///////////////////////////////////////
// Program branches here if any interrupt
// occurs.
//
void __INT(void) {

  if (PIR1.TMR1IF) { // TIMER1 interrupt
    PIR1.TMR1IF = 0; // Clear interrupt flag
    handle_TMR1();   // Call TIMER1 handler
  }

  if (PIR1.PSPIF) {  // PSPIE interrupt
    PIR1.PSPIF = 0;  // Clear interrupt flag
    handle_SLAVE();  // Call slave port handler
  }
  // If fall through here then an unexpected
  // interrupt occurred. Trap it by toggling
  // bit 0 in PORTC
    TRISC.0 = 0;
    PORTC.0 = 0;
    PORTC.0 = 1;
}

///////////////////////////////////////
// Timer interrupt handler
//
void handle_TMR1() {
  // Code for handling TIMER 1 overflow interrupt
#asm ( RETFIE);     // Return from interrupt
}

///////////////////////////////////////
// Interrupt handler for the parallel
// slave port.
//
void handle_SLAVE() {
  if (TRISE.IBF) {  // Input buffer full
    data = PORTD;   // Read data from slave port
    data = -data;   // Get two's complement
  }
  while (TRISE.OBF) // Loop until output buffer
    ;               // is read by microprocessor
  PORTD = data;     // then write the data out.
#asm ( RETFIE);     // Return from interrupt
}
