/*
   These routines may be adapted for any purpose when
   used with the MPC Code Development system.  No
   warranty is implied or given as to their usability
   for any purpose.

        (c) Copyright 1995

        Byte Craft Limited
        Waterloo, Ontario
        Canada N2J 4E4
        (519) 888-6911

        Sherif Abdel-Kader
*/
// This program implements a wakeup on keystroke.
// The PIC16C54 is put in sleep mode and wakes up
// when one of two switches SW1 and SW2 are pressed.
// The PIC16C54 then scans two inputs SCAN1 and SCAN2
// to find out which switch was pressed. If SW1 is
// pressed the green LED is turned on, whereas if
// SW2 is pressed the red LED is turned on.
// The PIC16C54 then waits till the key is released
// and sleeps again.
//
// For the circuit diagram of this simple application
// see Microchips' "Embedded Control Handbook",
// application note AN528 by Stan D'Souza.
//

#include <16C54.H>

// Pin assignments of PORT B
#define SW1        0
#define SW2        1
#define SCAN1      2
#define SCAN2      3
#define GREEN_LED  4
#define RED_LED    5

#define MSEC_20 20   // 20ms delay for 2MHz clock

unsigned int dur;    // Duration
unsigned int scan;   // Value scanned off switches

///////////////////////////////////////
//
void init_port_B(void) {
  /* Port B I/O assignments
     SW1, SW2     -> input
     SCAN1, SCAN2 -> output
     GREEN, RED   -> output
     RB6, RB7     -> don't care
  */
  __TRIS(0x03, PORTB);
  // Default values
     PORTB = 0xFF;
}

//////////////////////////////////////
//
void delay(dur) {
#asm
__dur RMB  1
DLY1
    CLRF   __dur
    DECFSZ dur
    GOTO  DLY2
    RETLW  0
DLY2
    DECFSZ __dur
    GOTO   DLY2
    GOTO   DLY1
#endasm
}

///////////////////////////////////////
// Determines which switch is pressed
// Uses:  scan (global variable)
//
void scan_keys() {
// Make SCAN1 and SCAN2 0's
   PORTB.SCAN1 = 0;
   PORTB.SCAN2 = 0;
// Check SW1 and SW2
   scan = PORTB & 0x03;
// Disable scanning
   PORTB.SCAN1 = 1;
   PORTB.SCAN2 = 1;
}

///////////////////////////////////////
// PIC16C54 goes here at RESET

void main() {
 // Initialize PORTB
     init_port_B();

 // Wait till capacitor charges
     delay(MSEC_20);

 // Check if key pressed
     scan_keys();

 // Turn LED(s) on
    switch(scan) {
      case 1: // Turn Red LED on
              PORTB.RED_LED = 0;
              break;
      case 2: // Turn Green LED on
              PORTB.GREEN_LED = 0;
              break;
      case 3: // Turn both LEDs on
              PORTB.GREEN_LED = 0;
              PORTB.RED_LED = 0;
              break;
    } // switch

 // Keep looping till key released
      do {
        delay(MSEC_20);
        scan_keys();
      } while(scan);

 // Turn scanning on and sleep
      PORTB.SCAN1 = 0;
      PORTB.SCAN2 = 0;
      SLEEP();
} // main
